==============
Release Naming
==============

Each OpenStack development cycle has a code-name that is
proposed and chosen by the community.  This name is frequently used in
preference to version numbers to refer to the release at the end of
the cycle.  The process of choosing the name should be an enjoyable
activity for the community to mark the software development cycle, and
the name itself should be fun to use.

Because the name will become associated with OpenStack, and a
particular release, the process should consider potential issues of
trademark.

Release Naming Process
----------------------

#. Anyone may propose a name that matches the `Release Name
   Criteria`_.  Proposed names should be added to a page on the
   OpenStack wiki.

#. A Condorcet election is held to rank the names. The electorate will be
   Technical Committee, and the poll should  be run in a manner that allows
   members of the community to see what each TC member voted for.

#. The Foundation will perform a trademark check on the winning name.
   If there is a trademark conflict, then the Foundation will proceed
   down the ranked list of Condorcet results until a name without a
   trademark conflict is found.  This will be the selected name.


Release Name Criteria
---------------------

The following rules are designed to provide some consistency in the
pattern used to select release names, provide a fun challenge in
finding names that meet the criteria, and prevent unwieldy names from
being chosen.

#. Each release name must start with the letter of the ISO basic Latin
   alphabet following the initial letter of the previous release,
   starting with the initial release of "Austin".  After "Z", the next
   name should start with "A" again.

#. The name must be composed only of the 26 characters of the ISO
   basic Latin alphabet.  Names which can be transliterated into this
   character set are also acceptable.

#. The name must be a single word with a maximum length of 10 characters.

Polls
-----

=======  =============  ================  ==========  ==========  ==================
Release  Coordinator    Nominations Open  Poll Open   Poll Close  Geographic Region
=======  =============  ================  ==========  ==========  ==================
M_       Monty Taylor   2015-06-01        2015-06-08  2015-06-15  Tokyo
N_       Monty Taylor   2015-11-08        2015-11-30  2015-12-07  Texas Hill Country
O_       Monty Taylor   2015-11-08        2015-11-30  2015-12-07  Catalonia
P_       Monty Taylor   2016-06-22        2016-07-06  2016-07-13  New England
Q_       Monty Taylor   2016-06-22        2016-07-06  2016-07-13  New South Wales
R_       Monty Taylor   2017-03-22        2017-04-05  2017-04-12  British Columbia
S_       Paul Belanger  2018-02-21        2018-03-14  2018-03-21  Berlin
T_       Tony Breeds    2018-09-15        2018-10-15  2018-10-22  Colorado
U_       Rico Lin       2019-07-01        2019-08-12  2019-08-19  China
V_       Sean McGinnis  2019-11-11        2019-12-09  2019-12-16  British Columbia
W_       Sean McGinnis  2020-01-20        2020-02-17  2020-02-23  N/A [*]_
X_       Sean McGinnis  2020-11-02        2020-11-30  2020-12-06  N/A
=======  =============  ================  ==========  ==========  ==================

.. [*] Starting with the W release, the naming criteria changed from referring
   to the physical or human geography of the region encompassing the location
   of the OpenStack Summit, to any name proposed by the community that starts
   with the designated release letter.

.. _M: http://lists.openstack.org/pipermail/openstack-dev/2015-July/069496.html
.. _N: http://lists.openstack.org/pipermail/openstack-dev/2016-January/084432.html
.. _O: http://lists.openstack.org/pipermail/openstack-dev/2016-January/084432.html
.. _P: http://lists.openstack.org/pipermail/openstack-dev/2016-August/101891.html
.. _Q: http://lists.openstack.org/pipermail/openstack-dev/2016-August/101891.html
.. _R: http://lists.openstack.org/pipermail/openstack-dev/2017-April/116100.html
.. _S: http://lists.openstack.org/pipermail/openstack-dev/2018-March/128899.html
.. _T: http://lists.openstack.org/pipermail/openstack-dev/2018-November/136464.html
.. _U: http://lists.openstack.org/pipermail/openstack-discuss/2019-August/008904.html
.. _V: http://lists.openstack.org/pipermail/openstack-discuss/2020-January/011947.html
.. _W: http://lists.openstack.org/pipermail/openstack-discuss/2020-March/013006.html
.. _X: http://lists.openstack.org/pipermail/openstack-discuss/2020-December/019537.html

